pub enum WasmtimeInstantiationStrategy {
PoolingCopyOnWrite,
RecreateInstanceCopyOnWrite,
Pooling,
RecreateInstance,
}Expand description
The instantiation strategy to use in compiled mode.
Variants
PoolingCopyOnWrite
Pool the instances to avoid initializing everything from scratch on each instantiation. Use copy-on-write memory when possible.
RecreateInstanceCopyOnWrite
Recreate the instance from scratch on every instantiation. Use copy-on-write memory when possible.
Pooling
Pool the instances to avoid initializing everything from scratch on each instantiation.
RecreateInstance
Recreate the instance from scratch on every instantiation. Very slow.