Struct sc_cli::KeystoreParams

source ·
pub struct KeystoreParams {
    pub keystore_uri: Option<String>,
    pub keystore_path: Option<PathBuf>,
    pub password_interactive: bool,
    pub password: Option<SecretString>,
    pub password_filename: Option<PathBuf>,
}
Parameters of the keystore

Fields

keystore_uri: Option<String>

Specify custom URIs to connect to for keystore-services

keystore_path: Option<PathBuf>

Specify custom keystore path.

password_interactive: bool

Use interactive shell for entering the password used by the keystore.

password: Option<SecretString>

Password used by the keystore. This allows appending an extra user-defined secret to the seed.

password_filename: Option<PathBuf>

File that contains the password used by the keystore.

Implementations

Get the keystore configuration for the parameters

Returns a vector of remote-urls and the local Keystore configuration

Examples found in repository?
src/config.rs (line 190)
188
189
190
191
192
	fn keystore_config(&self, config_dir: &PathBuf) -> Result<(Option<String>, KeystoreConfig)> {
		self.keystore_params()
			.map(|x| x.keystore_config(config_dir))
			.unwrap_or_else(|| Ok((None, KeystoreConfig::InMemory)))
	}
More examples
Hide additional examples
src/commands/insert_key.rs (line 69)
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
	pub fn run<C: SubstrateCli>(&self, cli: &C) -> Result<(), Error> {
		let suri = utils::read_uri(self.suri.as_ref())?;
		let base_path = self
			.shared_params
			.base_path()?
			.unwrap_or_else(|| BasePath::from_project("", "", &C::executable_name()));
		let chain_id = self.shared_params.chain_id(self.shared_params.is_dev());
		let chain_spec = cli.load_spec(&chain_id)?;
		let config_dir = base_path.config_dir(chain_spec.id());

		let (keystore, public) = match self.keystore_params.keystore_config(&config_dir)? {
			(_, KeystoreConfig::Path { path, password }) => {
				let public = with_crypto_scheme!(self.scheme, to_vec(&suri, password.clone()))?;
				let keystore: SyncCryptoStorePtr = Arc::new(LocalKeystore::open(path, password)?);
				(keystore, public)
			},
			_ => unreachable!("keystore_config always returns path and password; qed"),
		};

		let key_type =
			KeyTypeId::try_from(self.key_type.as_str()).map_err(|_| Error::KeyTypeInvalid)?;

		SyncCryptoStore::insert_unknown(&*keystore, key_type, &suri, &public[..])
			.map_err(|_| Error::KeyStoreOperation)?;

		Ok(())
	}

helper method to fetch password from KeyParams or read from stdin

Examples found in repository?
src/commands/sign.rs (line 57)
54
55
56
57
58
59
60
61
62
63
64
	pub fn run(&self) -> error::Result<()> {
		let message = utils::read_message(self.message.as_ref(), self.hex)?;
		let suri = utils::read_uri(self.suri.as_ref())?;
		let password = self.keystore_params.read_password()?;

		let signature =
			with_crypto_scheme!(self.crypto_scheme.scheme, sign(&suri, password, message))?;

		println!("{}", signature);
		Ok(())
	}
More examples
Hide additional examples
src/commands/generate.rs (line 63)
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
	pub fn run(&self) -> Result<(), Error> {
		let words = match self.words {
			Some(words) => MnemonicType::for_word_count(words).map_err(|_| {
				Error::Input(
					"Invalid number of words given for phrase: must be 12/15/18/21/24".into(),
				)
			})?,
			None => MnemonicType::Words12,
		};
		let mnemonic = Mnemonic::new(words, Language::English);
		let password = self.keystore_params.read_password()?;
		let output = self.output_scheme.output_type;

		with_crypto_scheme!(
			self.crypto_scheme.scheme,
			print_from_uri(mnemonic.phrase(), password, self.network_scheme.network, output)
		);
		Ok(())
	}
src/commands/inspect_key.rs (line 83)
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
	pub fn run(&self) -> Result<(), Error> {
		let uri = utils::read_uri(self.uri.as_ref())?;
		let password = self.keystore_params.read_password()?;

		if self.public {
			with_crypto_scheme!(
				self.crypto_scheme.scheme,
				print_from_public(
					&uri,
					self.network_scheme.network,
					self.output_scheme.output_type,
				)
			)?;
		} else {
			if let Some(ref expect_public) = self.expect_public {
				with_crypto_scheme!(
					self.crypto_scheme.scheme,
					expect_public_from_phrase(expect_public, &uri, password.as_ref())
				)?;
			}

			with_crypto_scheme!(
				self.crypto_scheme.scheme,
				print_from_uri(
					&uri,
					password,
					self.network_scheme.network,
					self.output_scheme.output_type,
				)
			);
		}

		Ok(())
	}