Struct sc_cli::LoggerBuilder [−][src]
A builder that is used to initialize the global logger.
Implementations
impl LoggerBuilder[src]
pub fn new<S>(directives: S) -> LoggerBuilder where
S: Into<String>, [src]
S: Into<String>,
Create a new LoggerBuilder which can be used to initialize the global logger.
pub fn with_profiling<S>(
&mut self,
tracing_receiver: TracingReceiver,
profiling_targets: S
) -> &mut LoggerBuilder where
S: Into<String>, [src]
&mut self,
tracing_receiver: TracingReceiver,
profiling_targets: S
) -> &mut LoggerBuilder where
S: Into<String>,
Set up the profiling.
pub fn with_log_reloading(&mut self, enabled: bool) -> &mut LoggerBuilder[src]
Wether or not to disable log reloading.
pub fn with_telemetry_buffer_size(
&mut self,
buffer_size: usize
) -> &mut LoggerBuilder[src]
&mut self,
buffer_size: usize
) -> &mut LoggerBuilder
Set a custom buffer size for the telemetry.
pub fn with_transport(&mut self, transport: ExtTransport) -> &mut LoggerBuilder[src]
Set a custom network transport (used for the telemetry).
pub fn with_colors(&mut self, enable: bool) -> &mut LoggerBuilder[src]
Force enable/disable colors.
pub fn init(self) -> Result<TelemetryWorker, Error>[src]
Initialize the global logger
This sets various global logging and tracing instances and thus may only be called once.