pub trait ChainSpec:
BuildStorage
+ Send
+ Sync {
Show 16 methods
// Required methods
fn name(&self) -> &str;
fn id(&self) -> &str;
fn chain_type(&self) -> ChainType;
fn boot_nodes(&self) -> &[MultiaddrWithPeerId];
fn telemetry_endpoints(&self) -> &Option<TelemetryEndpoints>;
fn protocol_id(&self) -> Option<&str>;
fn fork_id(&self) -> Option<&str>;
fn properties(&self) -> Map<String, Value>;
fn extensions(&self) -> &dyn GetExtension;
fn extensions_mut(&mut self) -> &mut dyn GetExtension;
fn add_boot_node(&mut self, addr: MultiaddrWithPeerId);
fn as_json(&self, raw: bool) -> Result<String, String>;
fn as_storage_builder(&self) -> &dyn BuildStorage;
fn cloned_box(&self) -> Box<dyn ChainSpec>;
fn set_storage(&mut self, storage: Storage);
fn code_substitutes(&self) -> BTreeMap<String, Vec<u8>>;
}Expand description
Common interface of a chain specification.
Required Methods
Sourcefn chain_type(&self) -> ChainType
fn chain_type(&self) -> ChainType
Type of the chain.
Sourcefn boot_nodes(&self) -> &[MultiaddrWithPeerId]
fn boot_nodes(&self) -> &[MultiaddrWithPeerId]
A list of bootnode addresses.
Sourcefn telemetry_endpoints(&self) -> &Option<TelemetryEndpoints>
fn telemetry_endpoints(&self) -> &Option<TelemetryEndpoints>
Telemetry endpoints (if any)
Sourcefn protocol_id(&self) -> Option<&str>
fn protocol_id(&self) -> Option<&str>
Network protocol id.
Sourcefn properties(&self) -> Map<String, Value>
fn properties(&self) -> Map<String, Value>
Additional loosely-typed properties of the chain.
Returns an empty JSON object if ‘properties’ not defined in config
Sourcefn extensions(&self) -> &dyn GetExtension
fn extensions(&self) -> &dyn GetExtension
Returns a reference to the defined chain spec extensions.
Sourcefn extensions_mut(&mut self) -> &mut dyn GetExtension
fn extensions_mut(&mut self) -> &mut dyn GetExtension
Returns a mutable reference to the defined chain spec extensions.
Sourcefn add_boot_node(&mut self, addr: MultiaddrWithPeerId)
fn add_boot_node(&mut self, addr: MultiaddrWithPeerId)
Add a bootnode to the list.
Sourcefn as_storage_builder(&self) -> &dyn BuildStorage
fn as_storage_builder(&self) -> &dyn BuildStorage
Return StorageBuilder for this spec.
Sourcefn cloned_box(&self) -> Box<dyn ChainSpec>
fn cloned_box(&self) -> Box<dyn ChainSpec>
Returns a cloned Box<dyn ChainSpec>.
Sourcefn set_storage(&mut self, storage: Storage)
fn set_storage(&mut self, storage: Storage)
Set the storage that should be used by this chain spec.
This will be used as storage at genesis.