Struct sc_cli::SharedParams
source · pub struct SharedParams {
pub chain: Option<String>,
pub dev: bool,
pub base_path: Option<PathBuf>,
pub log: Vec<String>,
pub detailed_log_output: bool,
pub disable_log_color: bool,
pub enable_log_reloading: bool,
pub tracing_targets: Option<String>,
pub tracing_receiver: TracingReceiver,
}Expand description
Shared parameters used by all CoreParams.
Fields
chain: Option<String>Specify the chain specification.
It can be one of the predefined ones (dev, local, or staging) or it can be a path to a file
with the chainspec (such as one exported by the build-spec subcommand).
dev: boolSpecify the development chain.
This flag sets --chain=dev, --force-authoring, --rpc-cors=all,
--alice, and --tmp flags, unless explicitly overridden.
base_path: Option<PathBuf>Specify custom base path.
log: Vec<String>Sets a custom logging filter. Syntax is <target>=<level>, e.g. -lsync=debug.
Log levels (least to most verbose) are error, warn, info, debug, and trace.
By default, all targets log info. The global log level can be set with -l<level>.
detailed_log_output: boolEnable detailed log output.
This includes displaying the log target, log level and thread name.
This is automatically enabled when something is logged with any higher level than info.
disable_log_color: boolDisable log color output.
enable_log_reloading: boolEnable feature to dynamically update and reload the log filter.
Be aware that enabling this feature can lead to a performance decrease up to factor six or more. Depending on the global logging level the performance decrease changes.
The system_addLogFilter and system_resetLogFilter RPCs will have no effect with this
option not being set.
tracing_targets: Option<String>Sets a custom profiling filter. Syntax is the same as for logging: <target>=<level>.
tracing_receiver: TracingReceiverReceiver to process tracing messages.
Implementations
sourcepub fn base_path(&self) -> Result<Option<BasePath>, Error>
pub fn base_path(&self) -> Result<Option<BasePath>, Error>
Specify custom base path.
Examples found in repository?
More examples
484 485 486 487 488 489 490 491 492 493 494 495
fn base_path(&self) -> Result<Option<BasePath>> {
Ok(if self.tmp {
Some(BasePath::new_temp_dir()?)
} else {
match self.shared_params().base_path()? {
Some(r) => Some(r),
// If `dev` is enabled, we use the temp base path.
None if self.shared_params().is_dev() => Some(BasePath::new_temp_dir()?),
None => None,
}
})
}59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85
pub fn run<C: SubstrateCli>(&self, cli: &C) -> Result<(), Error> {
let suri = utils::read_uri(self.suri.as_ref())?;
let base_path = self
.shared_params
.base_path()?
.unwrap_or_else(|| BasePath::from_project("", "", &C::executable_name()));
let chain_id = self.shared_params.chain_id(self.shared_params.is_dev());
let chain_spec = cli.load_spec(&chain_id)?;
let config_dir = base_path.config_dir(chain_spec.id());
let (keystore, public) = match self.keystore_params.keystore_config(&config_dir)? {
(_, KeystoreConfig::Path { path, password }) => {
let public = with_crypto_scheme!(self.scheme, to_vec(&suri, password.clone()))?;
let keystore: SyncCryptoStorePtr = Arc::new(LocalKeystore::open(path, password)?);
(keystore, public)
},
_ => unreachable!("keystore_config always returns path and password; qed"),
};
let key_type =
KeyTypeId::try_from(self.key_type.as_str()).map_err(|_| Error::KeyTypeInvalid)?;
SyncCryptoStore::insert_unknown(&*keystore, key_type, &suri, &public[..])
.map_err(|_| Error::KeyStoreOperation)?;
Ok(())
}sourcepub fn is_dev(&self) -> bool
pub fn is_dev(&self) -> bool
Specify the development chain.
Examples found in repository?
More examples
484 485 486 487 488 489 490 491 492 493 494 495
fn base_path(&self) -> Result<Option<BasePath>> {
Ok(if self.tmp {
Some(BasePath::new_temp_dir()?)
} else {
match self.shared_params().base_path()? {
Some(r) => Some(r),
// If `dev` is enabled, we use the temp base path.
None if self.shared_params().is_dev() => Some(BasePath::new_temp_dir()?),
None => None,
}
})
}59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85
pub fn run<C: SubstrateCli>(&self, cli: &C) -> Result<(), Error> {
let suri = utils::read_uri(self.suri.as_ref())?;
let base_path = self
.shared_params
.base_path()?
.unwrap_or_else(|| BasePath::from_project("", "", &C::executable_name()));
let chain_id = self.shared_params.chain_id(self.shared_params.is_dev());
let chain_spec = cli.load_spec(&chain_id)?;
let config_dir = base_path.config_dir(chain_spec.id());
let (keystore, public) = match self.keystore_params.keystore_config(&config_dir)? {
(_, KeystoreConfig::Path { path, password }) => {
let public = with_crypto_scheme!(self.scheme, to_vec(&suri, password.clone()))?;
let keystore: SyncCryptoStorePtr = Arc::new(LocalKeystore::open(path, password)?);
(keystore, public)
},
_ => unreachable!("keystore_config always returns path and password; qed"),
};
let key_type =
KeyTypeId::try_from(self.key_type.as_str()).map_err(|_| Error::KeyTypeInvalid)?;
SyncCryptoStore::insert_unknown(&*keystore, key_type, &suri, &public[..])
.map_err(|_| Error::KeyStoreOperation)?;
Ok(())
}sourcepub fn chain_id(&self, is_dev: bool) -> String
pub fn chain_id(&self, is_dev: bool) -> String
Get the chain spec for the parameters provided
Examples found in repository?
More examples
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85
pub fn run<C: SubstrateCli>(&self, cli: &C) -> Result<(), Error> {
let suri = utils::read_uri(self.suri.as_ref())?;
let base_path = self
.shared_params
.base_path()?
.unwrap_or_else(|| BasePath::from_project("", "", &C::executable_name()));
let chain_id = self.shared_params.chain_id(self.shared_params.is_dev());
let chain_spec = cli.load_spec(&chain_id)?;
let config_dir = base_path.config_dir(chain_spec.id());
let (keystore, public) = match self.keystore_params.keystore_config(&config_dir)? {
(_, KeystoreConfig::Path { path, password }) => {
let public = with_crypto_scheme!(self.scheme, to_vec(&suri, password.clone()))?;
let keystore: SyncCryptoStorePtr = Arc::new(LocalKeystore::open(path, password)?);
(keystore, public)
},
_ => unreachable!("keystore_config always returns path and password; qed"),
};
let key_type =
KeyTypeId::try_from(self.key_type.as_str()).map_err(|_| Error::KeyTypeInvalid)?;
SyncCryptoStore::insert_unknown(&*keystore, key_type, &suri, &public[..])
.map_err(|_| Error::KeyStoreOperation)?;
Ok(())
}sourcepub fn log_filters(&self) -> &[String]
pub fn log_filters(&self) -> &[String]
Get the filters for the logging
sourcepub fn detailed_log_output(&self) -> bool
pub fn detailed_log_output(&self) -> bool
Should the detailed log output be enabled.
sourcepub fn disable_log_color(&self) -> bool
pub fn disable_log_color(&self) -> bool
Should the log color output be disabled?
sourcepub fn enable_log_reloading(&self) -> bool
pub fn enable_log_reloading(&self) -> bool
Is log reloading enabled
sourcepub fn tracing_receiver(&self) -> TracingReceiver
pub fn tracing_receiver(&self) -> TracingReceiver
Receiver to process tracing messages.
sourcepub fn tracing_targets(&self) -> Option<String>
pub fn tracing_targets(&self) -> Option<String>
Comma separated list of targets for tracing.